searchData={"items":[{"type":"module","title":"CastParams","doc":"Plug for casting request params to defined types.","ref":"CastParams.html"},{"type":"module","title":"Usage - CastParams","doc":"```elixir\ndefmodule AccountController do\n  use AppWeb, :controller\n  use CastParams\n\n  # define params types\n  # :category_id - required integer param (raise CastParams.NotFound if not exists)\n  # :weight - float param, set nil if doesn't exists\n  cast_params category_id: :integer!, weight: :float\n\n  # defining for show action\n  # :name - is required string param\n  # :terms - is boolean param\n  cast_params name: :string!, terms: :boolean when action == :show\n\n  # received prepared params\n  def index(conn, %{\"category_id\" => category_id, \"weight\" => weight} = params) do\n  end\n\n  # received prepared params\n  def show(conn, %{\"category_id\" => category_id, \"terms\" => terms, \"weight\" => weight} = params) do\n  end\nend\n```","ref":"CastParams.html#module-usage"},{"type":"module","title":"Supported Types - CastParams","doc":"Each type can ending with a `!` to mark the parameter as required.\n\n* *`:boolean`*\n* *`:integer`*\n* *`:string`*\n* *`:float`*\n* *`:decimal`*","ref":"CastParams.html#module-supported-types"},{"type":"macro","title":"CastParams.cast_params/1","doc":"Stores a plug to be executed as part of the plug pipeline.","ref":"CastParams.html#cast_params/1"},{"type":"type","title":"CastParams.options/0","doc":"Options for use CastParams","ref":"CastParams.html#t:options/0"},{"type":"module","title":"CastParams.Config","doc":"Configure schema definition","ref":"CastParams.Config.html"},{"type":"module","title":"Options - CastParams.Config","doc":"* *`nulify`* - Set default param to nil. `true` - by default.","ref":"CastParams.Config.html#module-options"},{"type":"function","title":"CastParams.Config.init/1","doc":"Configure Schema","ref":"CastParams.Config.html#init/1"},{"type":"function","title":"Examples - CastParams.Config.init/1","doc":"iex> init(nulify: false)\n    %CastParams.Config{nulify: false}","ref":"CastParams.Config.html#init/1-examples"},{"type":"type","title":"CastParams.Config.t/0","doc":"","ref":"CastParams.Config.html#t:t/0"},{"type":"module","title":"CastParams.Plug","doc":"Define `Plug` for casting params to types described in `CastParams.Schema`","ref":"CastParams.Plug.html"},{"type":"function","title":"CastParams.Plug.call/2","doc":"","ref":"CastParams.Plug.html#call/2"},{"type":"function","title":"CastParams.Plug.init/1","doc":"","ref":"CastParams.Plug.html#init/1"},{"type":"module","title":"CastParams.Schema","doc":"Defines a params schema for a plug.\n\nA params schema is just a keyword list where keys are the parameter name\nand the value is either a valid `CastParams.Type` (ending with a `!` to mark the parameter as required).","ref":"CastParams.Schema.html"},{"type":"module","title":"Example - CastParams.Schema","doc":"CastParams.Schema.init(age: :integer, terms: :boolean!, name: :string, weight: :float)","ref":"CastParams.Schema.html#module-example"},{"type":"function","title":"CastParams.Schema.init/1","doc":"Init schema","ref":"CastParams.Schema.html#init/1"},{"type":"function","title":"Examples - CastParams.Schema.init/1","doc":"iex> init(age: :integer)\n    [%CastParams.Param{names: [\"age\"], type: :integer}]\n\n    iex> init([age: :integer!])\n    [%CastParams.Param{names: [\"age\"], type: :integer, required: true}]\n\n    iex> init([terms: :boolean!, name: :string, age: :integer])\n    [\n      %CastParams.Param{names: [\"terms\"], type: :boolean, required: true},\n      %CastParams.Param{names: [\"name\"], required: false, type: :string},\n      %CastParams.Param{names: [\"age\"], required: false, type: :integer},\n    ]","ref":"CastParams.Schema.html#init/1-examples"},{"type":"type","title":"CastParams.Schema.t/0","doc":"","ref":"CastParams.Schema.html#t:t/0"},{"type":"behaviour","title":"CastParams.Type","doc":"Define casting types","ref":"CastParams.Type.html"},{"type":"callback","title":"CastParams.Type.cast/1","doc":"Casts the given input to the custom type.","ref":"CastParams.Type.html#c:cast/1"},{"type":"function","title":"CastParams.Type.cast/2","doc":"Casts the given input to the custom type.","ref":"CastParams.Type.html#cast/2"},{"type":"function","title":"Basic types - CastParams.Type.cast/2","doc":"[:boolean, :integer, :string, :float, :decimal]","ref":"CastParams.Type.html#cast/2-basic-types"},{"type":"function","title":"Example - CastParams.Type.cast/2","doc":"iex> cast(:integer, \"1.0\")\n    {:ok, 1}\n    iex> cast(:integer, \"\")\n    {:error, :invalid}\n\n    iex> cast(:string, \"some string\")\n    {:ok, \"some string\"}\n    iex> cast(:string, nil)\n    {:ok, \"\"}\n\n    iex> cast(:integer, \"1\")\n    {:ok, 1}\n    iex> cast(:integer, \"1.0\")\n    {:ok, 1}\n\n    iex> cast(:boolean, \"1\")\n    {:ok, true}\n    iex> cast(:boolean, \"0\")\n    {:ok, false}\n\n    iex> cast(:float, \"1\")\n    {:ok, 1.0}\n    iex> cast(:float, \"1.0\")\n    {:ok, 1.0}\n\n    iex> cast(:decimal, \"1.001\")\n    {:ok, Decimal.new(\"1.001\")}","ref":"CastParams.Type.html#cast/2-example"},{"type":"function","title":"CastParams.Type.primitive_types/0","doc":"","ref":"CastParams.Type.html#primitive_types/0"},{"type":"callback","title":"CastParams.Type.type/0","doc":"Returns the type name for the custom type.","ref":"CastParams.Type.html#c:type/0"},{"type":"type","title":"CastParams.Type.custom/0","doc":"Custom types are represented by user-defined modules.","ref":"CastParams.Type.html#t:custom/0"},{"type":"type","title":"CastParams.Type.primitive/0","doc":"Primitive types.","ref":"CastParams.Type.html#t:primitive/0"},{"type":"type","title":"CastParams.Type.t/0","doc":"A type, primitive or custom.","ref":"CastParams.Type.html#t:t/0"},{"type":"exception","title":"CastParams.Error","doc":"","ref":"CastParams.Error.html"},{"type":"exception","title":"CastParams.NotFound","doc":"","ref":"CastParams.NotFound.html"},{"type":"extras","title":"CastParams","doc":"# CastParams\n-----\n[![Build Status][shield-travis]][travis-ci]\n[![Coverage Status][shield-coveralls]][docs]\n[![Version][shield-version]][hexpm]\n[![License][shield-license]][hexpm]\n\nCastParams is a powerful library for Elixir's [Plug][plug] that allows you to define parameter types and automatically cast incoming parameters to their respective types in a plug for `Phoenix.Controller` or `Plug.Router`. This simplifies the process of handling incoming parameters and reduces the amount of manual type checking and casting you need to do in your code.","ref":"readme.html"},{"type":"extras","title":"Features - CastParams","doc":"* **Type Casting**: Automatically cast incoming parameters to their defined types. This eliminates the need for manual type checking and casting in your code.\n* **Nullify Parameters**: If a parameter does not exist, it will be set to null. This prevents errors caused by undefined parameters.\n* **Required Types**: You can mark a type as required by ending it with a `!`. If a required parameter does not exist, an exception will be raised.\n* **Namespace Support**: CastParams supports namespaced parameters like `user[name]`.","ref":"readme.html#features"},{"type":"extras","title":"Usage - CastParams","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Phoenix Framework - CastParams","doc":"1. Add `use CastParams` inside your Phoenix controller or in `web.ex`. This will extend the controller module with the `cast_params/1` macro which allows you to define parameter types.\n2. Use the `cast_params` macro to define the types for your parameters. You can define types for all actions or for specific actions.\n3. In your action functions, you can now access the casted parameters directly from the params map.\n\nHere is an example:\n```elixir\ndefmodule AccountController do\n\n  use AppWeb, :controller\n  use CastParams\n  \n  # Define parameter types for all actions\n  # :category_id is a required integer parameter (CastParams.NotFound will be raised if it does not exist)\n  # :weight is a float parameter (will be set to nil if it does not exist)\n  cast_params category_id: :integer!, weight: :float\n\n  # Define parameter types for the show action\n  # :name is a required string parameter\n  # :terms is a boolean parameter  \n  cast_params name: :string!, terms: :boolean when action == :show\n\n  # Define parameter types for the create action\n  # user[name] is a string parameter\n  # user[subscribe] is a boolean parameter\n  cast_params user: [name: :string, subscribe: :boolean] when action == :create\n\n  # The index action receives the prepared parameters\n  def index(conn, %{\"category_id\" => category_id, \"weight\" => weight} = params) do\n    # Here you can use the casted parameters directly\n    # For example, you might use the category_id to fetch a category from the database\n    category = Repo.get(Category, category_id)\n    # Then you might use the weight to filter products in that category\n    products = Repo.all(from p in Product, where: p.category_id == ^category_id and p.weight   redirect(conn, to: user_path(conn, :show, user))\n      {:error, changeset} -> render(conn, \"new.html\", changeset: changeset)\n    end\n  end\nend\n```\n\n#","ref":"readme.html#phoenix-framework"},{"type":"extras","title":"Other Plug.Router Apps - CastParams","doc":"For other applications using `Plug.Router`, call the `cast_params` anytime after calling the `:match` and `:dispatch` plugs:\n\n```elixir\ndefmodule MyApp.Router do\n  use Plug.Router\n  use CastParams\n  plug :match\n  plug :dispatch\n\n  cast_params(category_id: :integer, terms: :boolean)\n  cast_params(name: :string)\n\n  get(\"/\", do: send_resp(conn, 200, \"ok\"))\nend\n```","ref":"readme.html#other-plug-router-apps"},{"type":"extras","title":"Supported Types - CastParams","doc":"Each type can ending with a `!` to mark the parameter as required.\n\n* *`:boolean`*\n* *`:integer`* \n* *`:string`* \n* *`:float`* \n* *`:decimal`*","ref":"readme.html#supported-types"},{"type":"extras","title":"Installation - CastParams","doc":"[Available in Hex](https://hex.pm/packages/cast_params), the package can be installed by adding `cast_params`to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:cast_params, \"~> 0.0.5\"} \n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Common Issues and Solutions - CastParams","doc":"If you encounter any issues while using CastParams, please check this section first. If your issue is not listed here, feel free to open an issue on the GitHub repository.","ref":"readme.html#common-issues-and-solutions"},{"type":"extras","title":"Contribution - CastParams","doc":"Contributions are always welcome! Feel free to send your PR with proposals, improvements, or corrections.","ref":"readme.html#contribution"},{"type":"extras","title":"License - CastParams","doc":"This software is licensed under [the MIT license](LICENSE.md).","ref":"readme.html#license"}],"content_type":"text/markdown"}